diff OrthancServer/Internals/FindScp.cpp @ 62:a70bb32802ae orthanc-renaming

renaming Server
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:33:19 +0200
parents 4bc019d2f969
children 428784e59dcd
line wrap: on
line diff
--- a/OrthancServer/Internals/FindScp.cpp	Sun Sep 16 09:30:31 2012 +0200
+++ b/OrthancServer/Internals/FindScp.cpp	Sun Sep 16 09:33:19 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -22,7 +22,7 @@
 
 #include "../FromDcmtkBridge.h"
 #include "../ToDcmtkBridge.h"
-#include "../../Core/PalanthirException.h"
+#include "../../Core/OrthancException.h"
 
 #include <dcmtk/dcmdata/dcfilefo.h>
 #include <dcmtk/dcmdata/dcmetinf.h>
@@ -31,7 +31,7 @@
 #include <dcmtk/dcmnet/diutil.h>
 
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace Internals
   {
@@ -74,7 +74,7 @@
         {
           data.handler_->Handle(data.input_, data.answers_);
         }
-        catch (PalanthirException& e)
+        catch (OrthancException& e)
         {
           // Internal error!
           OFLOG_ERROR(Internals::Logger, "IFindRequestHandler Failed: " << e.What());
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium